todoist.managers
----------------

.. automodule:: todoist.managers.projects
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: todoist.managers.items
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: todoist.managers.labels
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: todoist.managers.notes
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: todoist.managers.filters
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: todoist.managers.reminders
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: todoist.managers.locations
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: todoist.managers.user
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: todoist.managers.invitations
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: todoist.managers.collaborators
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: todoist.managers.collaborator_states
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: todoist.managers.biz_invitations
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: todoist.managers.live_notifications
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: todoist.managers.generic
    :members:
    :undoc-members:
    :show-inheritance:
